@@ -35,7 +35,7 @@ author = 'Zineb Aly, Tamas Gal, Johannes Schumann'
 extensions = [
     'sphinx.ext.autodoc', 'sphinx.ext.autosummary', 'sphinx.ext.viewcode',
     'autoapi.extension', 'numpydoc',
-    #'sphinx_gallery.gen_gallery'
+    'sphinx_gallery.gen_gallery'
 ]
 autosummary_generate = True
 
@@ -54,13 +54,14 @@ autoapi_options = ['members', 'undoc-members']
 autoapi_include_summaries = True
 
 # Gallery
-# sphinx_gallery_conf = {
-#     'backreferences_dir': 'modules/generated',
-#     'examples_dirs': '../examples',  # path to your example scripts
-#     'gallery_dirs':
-#     'auto_examples',  # path to where to save gallery generated output
-#     'show_memory': True,
-# }
+sphinx_gallery_conf = {
+    'backreferences_dir': 'modules/generated',
+    'default_thumb_file': '_static/default_gallery_thumbnail.png',
+    'examples_dirs': '../examples',  # path to your example scripts
+    'gallery_dirs':
+    'auto_examples',  # path to where to save gallery generated output
+    'show_memory': True,
+}
 
 # -- Options for HTML output -------------------------------------------------
 
@@ -73,5 +74,5 @@ html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-# html_static_path = ['_static']
+html_static_path = ['_static']
 html_title = "km3io {}".format(version)
