@@ -6,7 +6,8 @@
 import uproot
 import numpy as np
 import warnings
-from .tools import Branch, BranchMapper, cached_property
+from .rootio import Branch, BranchMapper
+from .tools import cached_property
 MAIN_TREE_NAME = "Events"
 
 
@@ -17,14 +18,11 @@ class GSGReader:
 
         Parameters
         ----------
-        file_path : path-like object
-            Path to the file of interest. It can be a str or any python
-            path-like object that points to the file.
+        file_path : file path or file-like object
+            The file handler. It can be a str or any python path-like object
+            that points to the file.
         """
-        if file_path is not None:
-            self._fobj = uproot.open(file_path)
-        else:
-            self._fobj = fobj
+        self._fobj = uproot.open(file_path)
 
     @cached_property
     def header(self):
@@ -45,11 +43,4 @@ class GSGReader:
 
     @cached_property
     def events(self):
-        gseagen_events_mapper = BranchMapper(name="Events",
-                                             key="Events",
-                                             extra={},
-                                             exclude={},
-                                             update={},
-                                             attrparser=lambda x: x,
-                                             flat=True)
-        return Branch(self._fobj, gseagen_events_mapper)
+        return Branch(self._fobj, BranchMapper(name="Events", key="Events"))
